==> mx-menu-editor_19.5.tar.xz: mx-menu-editor-19.5/translations/mx-menu-editor_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="../addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Kategoriler</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Kategori ekle</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Kategori sil</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Komut:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Değişiklikleri kaydet</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="169"/>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Ad:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Yorum:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Simge:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="222"/>
        <location filename="../addappdialog.cpp" line="122"/>
        <source>Set icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Uçbirimde Çalıştır</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="37"/>
        <source>Add Custom Application</source>
        <translation>Özel Uygulama Ekle</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="54"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="54"/>
        <source>Could not save the file</source>
        <translation>Dosya kaydedilemedi</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Save changes?</source>
        <translation>Değişiklikler kaydedilsin mi?</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Do you want to save your edits?</source>
        <translation>Düzenlemelerinizi kaydetmek istiyor musunuz?</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>MX Menu Editor</source>
        <translation>MX Menü Düzenleyici</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="34"/>
        <source>Advanced Editor</source>
        <translation>Gelişmiş Düzenleyici</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Categories and applications</source>
        <translation>Kategoriler ve uygulamalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Add custom application</source>
        <translation>Özel uygulama ekle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Run in terminal</source>
        <translation>Uçbirimde çalıştır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>Hide</source>
        <translation>Gizle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Notify startup</source>
        <translation>Başlangıçta bildir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Quick Editor</source>
        <translation>Çabuk düzenleyici</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Comment:</source>
        <translation>Yorum:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Restore original item</source>
        <translation>Özgün öğeyi geri yükle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Command:</source>
        <translation>Komut:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>Select...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Name:</source>
        <translation>Ad:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>Icon</source>
        <translation>Simge</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <location filename="../mainwindow.cpp" line="541"/>
        <source>Change icon</source>
        <translation>Simgeyi değiştir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Categories</source>
        <translation>Kategoriler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>Display help</source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Save Changes</source>
        <translation>Değişiklikleri kaydet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Select executable file</source>
        <translation>Çalıştırılabilir dosyayı seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation>Resim Dosyaları  (*.png *.jpg *.bmp *.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="718"/>
        <source>Choose category</source>
        <translation>Kategori seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="729"/>
        <location filename="../mainwindow.cpp" line="845"/>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="730"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="820"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="820"/>
        <source>Could not save the file</source>
        <translation>Dosya kaydedilemedi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="838"/>
        <source>About MX Menu Editor</source>
        <translation>MX Menü Düzenleyici Hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>Version: </source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>Program for editing Xfce menu</source>
        <translation>Xfce menüsünü düzenleme programı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="842"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="843"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="844"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="860"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Save changes?</source>
        <translation>Değişiklikler kaydedilsin mi?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Do you want to save your edits?</source>
        <translation>Düzenlemelerinizi kaydetmek istiyor musunuz?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>You must run this program as normal user.</source>
        <translation>Bu programı normal kullanıcı olarak çalıştırmalısınız.</translation>
    </message>
</context>
</TS>

==> mx-menu-editor_21.7.01.tar.xz: mx-menu-editor-21.7.01/translations/mx-menu-editor_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="../addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Kategoriler</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Kategori ekle</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Kategori sil</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Komut:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Değişiklikleri kaydet</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation>Diyaloğu Sonlandır</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="169"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation>Seç...</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Ad:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Yorum:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Simge:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="222"/>
        <location filename="../addappdialog.cpp" line="111"/>
        <source>Set icon</source>
        <translation>Simge ayarla</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Uçbirimde Çalıştır</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation>Başlangıç Bildirimi</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="35"/>
        <source>Add Custom Application</source>
        <translation>Özel Uygulama Ekle</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="51"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="51"/>
        <source>Could not save the file</source>
        <translation>Dosya kaydedilemedi</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="93"/>
        <source>Save changes?</source>
        <translation>Değişiklikler kaydedilsin mi?</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="93"/>
        <source>Do you want to save your edits?</source>
        <translation>Düzenlemelerinizi kaydetmek istiyor musunuz?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Kaydet</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="826"/>
        <source>MX Menu Editor</source>
        <translation>MX Menü Düzenleyici</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="34"/>
        <source>Advanced Editor</source>
        <translation>Gelişmiş Düzenleyici</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Categories and applications</source>
        <translation>Kategoriler ve uygulamalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Add custom application</source>
        <translation>Özel uygulama ekle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Run in terminal</source>
        <translation>Uçbirimde çalıştır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>Hide</source>
        <translation>Gizle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Notify startup</source>
        <translation>Başlangıçta bildir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Quick Editor</source>
        <translation>Çabuk düzenleyici</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Comment:</source>
        <translation>Yorum:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Restore original item</source>
        <translation>Özgün öğeyi geri yükle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Command:</source>
        <translation>Komut:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>Select...</source>
        <translation>Seç...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Name:</source>
        <translation>Ad:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>Icon</source>
        <translation>Simge</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Change icon</source>
        <translation>Simgeyi değiştir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Categories</source>
        <translation>Kategoriler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>Display help</source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Save Changes</source>
        <translation>Değişiklikleri kaydet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Select executable file</source>
        <translation>Çalıştırılabilir dosyayı seçin</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation type="vanished">Resim Dosyaları  (*.png *.jpg *.bmp *.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="700"/>
        <source>Choose category</source>
        <translation>Kategori seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <location filename="../mainwindow.cpp" line="832"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="809"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="809"/>
        <source>Could not save the file</source>
        <translation>Dosya kaydedilemedi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>About MX Menu Editor</source>
        <translation>MX Menü Düzenleyici Hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="826"/>
        <source>Version: </source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="827"/>
        <source>Program for editing Xfce menu</source>
        <translation>Xfce menüsünü düzenleme programı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="831"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="892"/>
        <source>Save changes?</source>
        <translation>Değişiklikler kaydedilsin mi?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="893"/>
        <source>Do you want to save your edits?</source>
        <translation>Düzenlemelerinizi kaydetmek istiyor musunuz?</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>You must run this program as normal user.</source>
        <translation>Bu programı normal kullanıcı olarak çalıştırmalısınız.</translation>
    </message>
</context>
</TS>
